@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/chgrp.c,v 1.11 2001/06/15 16:36:36 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/chgrp.c,v 1.12 2004/03/21 14:13:11 werner Exp $
  *
  * Change Group
  *
@@ -65,7 +65,7 @@ int GetNewGroup(int st_gid)
 
   MvAddStr( LINES - 2, 1, "New Group:" );
 
-  if( InputString( group, LINES - 2, 12, GROUP_NAME_MAX, "\r\033" ) == CR )
+  if( InputString( group, LINES - 2, 12, 0, GROUP_NAME_MAX, "\r\033" ) == CR )
   {
     if( (group_id = GetGroupId( group )) == -1 )
     {
