@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/chown.c,v 1.11 2001/06/15 16:36:36 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/chown.c,v 1.12 2004/03/21 14:13:11 werner Exp $
  *
  * Change Owner
  *
@@ -65,7 +65,7 @@ int GetNewOwner(int st_uid)
 
   MvAddStr( LINES - 2, 1, "New Owner:" );
 
-  if( InputString( owner, LINES - 2, 12, OWNER_NAME_MAX, "\r\033" ) == CR )
+  if( InputString( owner, LINES - 2, 12, 0, OWNER_NAME_MAX, "\r\033" ) == CR )
   {
     if( (owner_id = GetPasswdUid( owner )) == -1 )
     {
