@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/dirwin.c,v 1.23 2003/08/31 11:11:00 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/dirwin.c,v 1.24 2004/11/13 21:08:05 werner Exp $
  *
  * Funktionen zur Handhabung des DIR-Windows
  *
@@ -671,19 +671,21 @@ void HandleTagAllDirs(DirEntry *dir_entry, BOOL value )
 	for(fe_ptr=dir_entry_list[i].dir_entry->file; fe_ptr; fe_ptr=fe_ptr->next)
 	{
 	    if( (fe_ptr->matching) && (fe_ptr->tagged != value) )
-	    if (value)
 	    {
-		fe_ptr->tagged = value;
-	       	dir_entry->tagged_files++;
-		dir_entry->tagged_bytes += fe_ptr->stat_struct.st_size;
-	       	statistic.disk_tagged_files++;
-		statistic.disk_tagged_bytes += fe_ptr->stat_struct.st_size;
-	    }else{
-		fe_ptr->tagged = value;
-	       	dir_entry->tagged_files--;
-		dir_entry->tagged_bytes -= fe_ptr->stat_struct.st_size;
-	       	statistic.disk_tagged_files--;
-		statistic.disk_tagged_bytes -= fe_ptr->stat_struct.st_size;
+	        if (value)
+	        {
+		    fe_ptr->tagged = value;
+	       	    dir_entry->tagged_files++;
+		    dir_entry->tagged_bytes += fe_ptr->stat_struct.st_size;
+	       	    statistic.disk_tagged_files++;
+		    statistic.disk_tagged_bytes += fe_ptr->stat_struct.st_size;
+	        }else{
+		    fe_ptr->tagged = value;
+	       	    dir_entry->tagged_files--;
+		    dir_entry->tagged_bytes -= fe_ptr->stat_struct.st_size;
+	       	    statistic.disk_tagged_files--;
+		    statistic.disk_tagged_bytes -= fe_ptr->stat_struct.st_size;
+	        }
 	    }
 	}
     }
@@ -816,7 +818,6 @@ void HandleSwitchWindow(DirEntry *dir_entry, DirEntry *start_dir_entry, BOOL *ne
 int HandleDirWindow(DirEntry *start_dir_entry)
 {
   DirEntry  *dir_entry, *de_ptr;
-  FileEntry *fe_ptr;
   int i, ch, unput_char;
   BOOL need_dsp_help;
   char new_name[PATH_LENGTH + 1];
@@ -824,6 +825,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
   char *home;
 
   unput_char = 0;
+  de_ptr = NULL;
 
   GetMaxYX(dir_window, &window_height, &window_width);
 
