@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.29 2003/08/31 11:11:00 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.31 2004/11/13 20:38:40 werner Exp $
  *
  * Funktionen zur Handhabung des FILE-Windows
  *
@@ -61,6 +61,9 @@ static int  DeleteTaggedFiles(int max_dispfiles);
 static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */), 
 			           WalkingPackage *walking_package
 			          );
+static void SilentTagWalkTaggedFiles( int (*fkt) (/* ??? */), 
+			           WalkingPackage *walking_package
+			          );
 static void RereadWindowSize(DirEntry *dir_entry);
 
 
@@ -2617,6 +2620,49 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      need_dsp_help = TRUE;
 		      break;
     
+      case 'S' & 0x1F :		/* --crb3 31dec03	*/
+                      if( !IsMatchingTaggedFiles() )
+                      {
+                        beep();
+                      }
+		      else if( mode != DISK_MODE && mode != USER_MODE )
+		      {
+			MESSAGE( "I am sorry*^S not supported in Archive-mode" );
+		      }
+		      else
+		      {
+			char *command_line;
+
+			if( ( command_line = (char *)malloc( COLS + 1 ) ) == NULL )
+			{
+			  ERROR_MSG( "Malloc failed*ABORT" );
+			  exit( 1 );
+			}
+
+			need_dsp_help = TRUE;
+			*command_line = '\0';
+		        if( !GetSearchCommandLine( command_line ) ) 
+			{
+			  refresh();
+			  endwin();
+			  walking_package.function_data.execute.command = command_line;
+                          SilentTagWalkTaggedFiles( ExecuteCommand,
+					            &walking_package
+					          );
+			  RefreshWindow( file_window ); 
+			  
+			  HitReturnToContinue();
+
+			  DisplayFiles( dir_entry, 
+					dir_entry->start_file, 
+					dir_entry->start_file + dir_entry->cursor_pos,
+					start_x
+				      );
+			}  
+			free( command_line );
+		      }
+		      break;
+                      
       case 'X' & 0x1F:
 		      if( !IsMatchingTaggedFiles() )
 		      {
@@ -2624,7 +2670,7 @@ int HandleFileWindow(DirEntry *dir_entry)
 		      }
 		      else if( mode != DISK_MODE && mode != USER_MODE )
 		      {
-			MESSAGE( "i am sorry*^X not supported in Archive-mode" );
+			MESSAGE( "I am sorry*^X not supported in Archive-mode" );
 		      }
 		      else
 		      {
@@ -2646,7 +2692,6 @@ int HandleFileWindow(DirEntry *dir_entry)
                           SilentWalkTaggedFiles( ExecuteCommand,
 					         &walking_package
 					       );
-		 	  
 			  HitReturnToContinue();
 
 			  DisplayFiles( dir_entry, 
@@ -2784,8 +2829,14 @@ static void WalkTaggedFiles(int start_file,
   if( baudrate() >= QUICK_BAUD_RATE ) typeahead( -1 );
 }
 
+/*
+ ExecuteCommand (*fkt) had its retval zeroed as found.
+ ^S needs that value, so it was unzeroed. forloop below
+ was modified to not care about retval instead?  
+ global flag for stop-on-error? does anybody want it? 
 
-
+ --crb3 12mar04
+*/
 
 static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */), 
 			           WalkingPackage *walking_package
@@ -2796,7 +2847,7 @@ static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */),
   int       result = 0;
 
   
-  for( i=0; i < (int)file_count && result == 0; i++ )
+  for( i=0; i < (int)file_count; i++ )
   {
     fe_ptr = file_entry_list[i].file;
 
@@ -2807,6 +2858,46 @@ static void SilentWalkTaggedFiles( int (*fkt) (/* ??? */),
   }
 }
 
+/*
+
+SilentTagWalkTaggedFiles.
+revision of above function to provide something like
+XTG's <search> facility, using external grep. 
+- loops for entire filescount.
+- if called program returns 1 (grep's "no-match" retcode), untags the file.
+repeated calls can be used to pare down tags, each with a different
+string, until only the intended target files are tagged.
+
+ExecuteCommand must have its retval unzeroed.
+
+--crb3 31dec03
+
+*/ 
+
+static void SilentTagWalkTaggedFiles( int (*fkt) (/* ??? */), 
+			           WalkingPackage *walking_package
+			          )
+{
+  FileEntry *fe_ptr;
+  int       i;
+  int       result = 0;
+
+  
+  for( i=0; i < (int)file_count; i++ )
+  {
+    fe_ptr = file_entry_list[i].file;
+
+    if( fe_ptr->tagged && fe_ptr->matching )
+    {
+      result = fkt( fe_ptr, walking_package );
+
+      if( result == 0 ) {
+      	fe_ptr->tagged = FALSE;
+      }
+    }
+  }
+}
+
 
 
 
