@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.20 2001/11/03 17:56:08 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.21 2004/11/13 20:38:40 werner Exp $
  *
  * Ermittlung der freien Plattenkapazitaet
  *
@@ -19,7 +19,7 @@
 #if defined( SVR4 ) || defined( OSF1 ) || defined( sun56 )
 #include <sys/statvfs.h>
 #else
-#if ( defined( ultrix ) || defined(openbsd) || defined ( __FreeBSD__ ) )
+#if ( defined( ultrix ) || defined(openbsd) || defined ( __FreeBSD__ ) || defined (__APPLE__) )
 #include <sys/param.h>
 #include <sys/mount.h>
 #else
@@ -189,7 +189,7 @@ int GetDiskParameter( char *path,
               fname = "HURD";
        }
 #else
-#if defined( sun56 ) || defined( sun ) || defined( hpux ) || defined( __NeXT__ ) || defined( ultrix ) || defined ( __FreeBSD__ )
+#if defined( sun56 ) || defined( sun ) || defined( hpux ) || defined( __NeXT__ ) || defined( ultrix ) || defined ( __FreeBSD__ ) || defined (__APPLE__)
         fname = "UNIX";
 #else
 #ifdef WIN32
