@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/match.c,v 1.15 2001/11/03 17:56:08 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/match.c,v 1.16 2004/11/13 20:38:40 werner Exp $
  *
  * Behandlung reg. Ausdruecke fuer Dateinamen
  *
@@ -9,7 +9,7 @@
 
 #include "ytree.h"
 
-#if defined( bsd ) || defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) || defined( __FreeBSD__ ) || defined( __GNU__ ) || defined( __FreeBSD__ )
+#if defined( bsd ) || defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) || defined( __FreeBSD__ ) || defined( __GNU__ )
 #define HAS_REGEX
 #endif
 
@@ -19,7 +19,7 @@
 #define _REGEX_RE_COMP
 #endif
 
-#if defined( hpux )
+#if defined( hpux ) || defined ( __APPLE__ )
 #define HAS_REGCOMP
 #endif
 
