@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/mkdir.c,v 1.15 2003/06/06 19:47:26 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/mkdir.c,v 1.16 2004/03/21 14:13:11 werner Exp $
  *
  * Erstellen von Verzeichnissen
  *
@@ -29,7 +29,7 @@ int MakeDirectory(DirEntry *father_dir_entry)
 
   *dir_name = '\0';
 
-  if( InputString( dir_name, LINES - 2, 20, COLS - 20 - 1, "\r\033" ) == CR )
+  if( InputString( dir_name, LINES - 2, 20, 0, COLS - 20 - 1, "\r\033" ) == CR )
   {
     result = MakeDirEntry( father_dir_entry, dir_name );
   }
