@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.29 2003/08/31 11:11:00 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.31 2004/11/13 21:08:05 werner Exp $
  *
  * Diverse Hilfsfunktionen
  *
@@ -8,7 +8,7 @@
 
 
 #include "ytree.h"
-
+#include "xmalloc.h"
 
 
 typedef struct
@@ -324,9 +324,12 @@ void PrintSpecialString(WINDOW *win, int y, int x, char *str, int color)
     else
             ch = ACS_BLOCK;
 #ifdef COLOR_SUPPORT
-    ch |= COLOR_PAIR(color) | A_BOLD;
+    wattrset( win, COLOR_PAIR(color) | A_BOLD );
 #endif /* COLOR_SUPPORT */
     waddch( win, ch );
+#ifdef COLOR_SUPPORT
+    wattrset( win, 0 );
+#endif /* COLOR_SUPPORT */
   }
 }
 
@@ -345,11 +348,12 @@ void Print(WINDOW *win, int y, int x, char *str, int color)
     ch = PRINT((int) *str);
    
 #ifdef COLOR_SUPPORT
-    ch |= (COLOR_PAIR(color) | A_BOLD);
+    wattrset( win, COLOR_PAIR(color) | A_BOLD);
 #else
-    ch |= color;
+    wattrset( win, color);
 #endif
     waddch(win, ch );
+    wattrset( win, 0);
   }
 }
 
@@ -405,11 +409,12 @@ void PrintOptions(WINDOW *win, int y, int x, char *str)
      }
 
 #ifdef COLOR_SUPPORT
-     ch |= (COLOR_PAIR(color) | A_BOLD);
+    wattrset( win, COLOR_PAIR(color) | A_BOLD);
 #else
-     ch |= color;
+    wattrset( win, color);
 #endif
      mvwaddch( win, y, x++, ch );
+     wattrset( win, 0 );
    }
 }
 
@@ -453,11 +458,12 @@ void PrintMenuOptions(WINDOW *win,int y, int x, char *str, int ncolor, int hcolo
     }
 
 #ifdef COLOR_SUPPORT
-    ch |= (COLOR_PAIR(color) | A_BOLD);
+    wattrset( win, COLOR_PAIR(color) | A_BOLD);
 #else
-    ch |= color;
+    wattrset( win, color);
 #endif
     mvwaddch(win, y, x++, ch );
+    wattrset( win, 0 );
   }
 }
 
@@ -1074,7 +1080,7 @@ static char *GNU_getcwd()
 
   while (1)
     {
-      char *buffer = (char *) malloc (size);
+      char *buffer = (char *) xmalloc (size);
       if (getcwd (buffer, size) == buffer)
         return buffer;
       free (buffer);
