@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.34 2003/08/31 11:11:00 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.36 2004/11/13 20:38:40 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -83,6 +83,11 @@ extern char *getcwd();
 #define LONGLONG		long long
 #define HAS_LONGLONG		1
 #else
+#ifdef __APPLE__
+#define STATFS(a, b, c, d )     statfs( a, b )
+#define LONGLONG		long long
+#define HAS_LONGLONG		1
+#else
 #ifdef __FreeBSD__
 #define STATFS(a, b, c, d )     statfs( a, b )
 #define LONGLONG		long long
@@ -144,6 +149,7 @@ extern char *getcwd();
 #endif /* SVR4 */
 #endif /* SVR3 */
 #endif /* OSF1 */
+#endif /* __APPLE__ */
 #endif /* __FreeBSD__ */
 #endif /* openbsd */
 
@@ -468,6 +474,7 @@ extern char *getcwd();
 #define DIR2          GetProfileValue( "DIR2" )
 #define FILE1         GetProfileValue( "FILE1" )
 #define FILE2         GetProfileValue( "FILE2" )
+#define SEARCHCOMMAND GetProfileValue( "SEARCHCOMMAND" )
  
 
 #define DEFAULT_TREE       "."
@@ -941,7 +948,7 @@ extern void DisplayFileSpec(void);
 extern void QuitTo(DirEntry * dir_entry);
 extern void Quit(void);
 extern int  ReadFileSpec(void);
-extern int  InputString(char *s, int y, int x, int length, char *term);
+extern int  InputString(char *s, int y, int x, int cursor_pos, int length, char *term);
 extern void RotateFileMode(void);
 extern int  Execute(DirEntry *dir_entry, FileEntry *file_entry);
 extern int  Pipe(DirEntry *dir_entry, FileEntry *file_entry);
@@ -979,6 +986,7 @@ extern int  GetAvailBytes(LONGLONG *avail_bytes);
 extern int  DeleteDirectory(DirEntry *dir_entry);
 extern int  ExecuteCommand(FileEntry *fe_ptr, WalkingPackage *walking_package);
 extern int  GetCommandLine(char *command_line);
+extern int  GetSearchCommandLine(char *command_line);
 extern int  DeleteFile(FileEntry *fe_ptr);
 extern int  RemoveFile(FileEntry *fe_ptr);
 extern int  RenameDirectory(DirEntry *de_ptr, char *new_name);
